@@ -62,7 +62,7 @@ def test_runner(self):
 
                         if getattr(settings, 'SMOKNUR_PRINT_REQUESTS', False):
                             sys.stdout.write(
-                                ERROR_TEXT.format(
+                                u'line={0}, file={1}, url={2}, post_params={3}'.format(
                                     index,
                                     f,
                                     req['url'],
@@ -75,7 +75,7 @@ def test_runner(self):
                             )
                         except:
                             sys.stdout.write(
-                                ERROR_TEXT.format(
+                                u'line={0}, file={1}, url={2}, post_params={3}'.format(
                                     index,
                                     f,
                                     req['url'],
@@ -91,11 +91,12 @@ def test_runner(self):
 
                         self.assertTrue(
                             resp.status_code in (200, 302),
-                            ERROR_TEXT.format(
+                            u'line={0}, file={1}, url={2}, post_params={3}, status_code={4}'.format(
                                 index,
                                 f,
                                 req['url'],
-                                req['params']).encode('utf-8'))
+                                req['params'],
+                                resp.status_code).encode('utf-8'))
 
 exclude_apps = getattr(settings, 'SMOKNUR_EXCLUDE_APPS', ())
 
